#include "Percolator.h"
#include "PercolatorCodes.h"
#include "PercoLooper.h"
#include "Verbosity.h"

//Constructor and destructor:

Percolator::Percolator()
  :BApplication("application/x-vnd.Be-PERC")
{
  thr_PercoManager = new BPercoManager();
  thr_PercoManager->Run();

  status_t cookie;

  lnk_Manager = new BMessenger(NULL, (BLooper *)thr_PercoManager, &cookie);
  VerboseReply(cookie, "creating the manager messenger", true);
};

Percolator::~Percolator()
{
  //first, clean up all of the messengers.
  if (lnk_Manager)
    delete lnk_Manager;
    
  //second, clean up all the remaining threads.
  if (thr_PercoManager->Lock())
    thr_PercoManager->Quit();
};

//inherited functions:

void Percolator::MessageReceived(BMessage *msg_received)
{
  switch (msg_received->what)
  {
    case B_PERCOLATOR_START_CONDUIT:
      SpawnPercoLooper(msg_received);
    break;
    case B_PERCOLATOR_TERMINATE_REQUEST:
      DisposeThread(msg_received);
    break;
    default:
      BApplication::MessageReceived(msg_received);
  };
};

//new functions:

void Percolator::SpawnPercoLooper(BMessage *msg_request)
{
  status_t cookie;
  cookie = msg_request->AddMessenger("Be:PERC:manager", *lnk_Manager);
  VerboseReply(cookie, "adding messenger to loop constructor", true);
  
  BPercoLooper *thr_New = new BPercoLooper(msg_request);
  thr_New->Run();
};

//MessageReceived helper functions:

void Percolator::DisposeThread(BMessage *msg_destruct)
{
  void *tmp_thr_Destruct;
  msg_destruct->FindPointer("Be:PERC:destroy",&tmp_thr_Destruct);
  if (tmp_thr_Destruct)
  {
    BPercoLooper *thr_Destruct = (BPercoLooper *)tmp_thr_Destruct;
    thr_Destruct->Lock();
    thr_Destruct->Quit();			//thread deletes itself.
  };
};

int main()
{
  Percolator *app_Percolator = new Percolator();
  
  app_Percolator->Run();
  
  delete app_Percolator;
};