//PercolatorConduit.h -- this is the file which defines the percolator
//conduit class.

#ifndef __B_PERCOLATOR_CONDUIT_H
#define __B_PERCOLATOR_CONDUIT_H

#if __BUILDING_PERCOLATOR_CONDUIT_H
  #define __PERCOLATOR_CONDUIT_TYPED __declspec(dllimport)
#else
  #define __PERCOLATOR_CONDUIT_TYPED __declspec(dllexport)
#endif

#include <Looper.h>
#include <Entry.h>
#include <Path.h>

#if __B_NAMESPACED
namespace Percolator {
#endif

class BMessenger;
class BMessage;
class BPercoView;
class BPercoLinker;
class BRect;

class __PERCOLATOR_CONDUIT_TYPED BPercolatorConduit
{
  public:
    BPercolatorConduit(BRect frame, const char *name, uint32 resizingMode, uint32 flags, uint32 pflags = 0);	//constructor
    BPercolatorConduit(BView *vww_replace, uint32 pflags = 0);
    virtual ~BPercolatorConduit();							//destructor
    
    //control functions
    status_t	SendFile(entry_ref &refs);
    status_t	SendFile(BPath path);
    void		SetFlags(int32 flags);
    status_t	GetStatus();
    
    status_t	Initialize(const char *type);
    status_t	ResetType(const char *type);
    status_t	SuspendConnection();
    status_t	RestartConnection();
    status_t	TerminateConnection();
    
    //linking functions
    
    void		SwapConnection(BMessenger *lnk_percolator);
    
    //Output functions
    BPercoView	*View();
    
    //openly viewable variables.
    
    BRect		rct_StartFrame;
    
  protected:
  
    //Local variables
    BMessenger		*lnk_Percolator;
    BMessenger		*lnk_This;
    BPercoView		*vww_Output;
    BPercoLinker	*thr_Looper;
    BString			*str_Name;
    BString			*str_Typecode;

    
    uint32		flg_Settings;
    uint32		flg_Status;
    status_t	rpt_Token;
    
};

//various errors.
#define B_PERCOLATOR_ERROR_BASE			B_GENERAL_ERROR_BASE + 0xb000

enum
{
  B_PERCO_CONDUIT_ERROR = B_PERCOLATOR_ERROR_BASE,
  B_PERCO_UNINITIALIZED_CONDUIT,
  B_PERCO_BROKEN_CONDUIT,
  B_PERCO_CLOSED_CONDUIT,
  B_PERCO_LOCAL_IMAGE_ERROR,
  B_PERCO_BAD_LOCAL_IMAGE,
  B_PERCO_ABSENT_LOCAL_IMAGE,
  B_PERCO_FAR_IMAGE_ERROR,
  B_PERCO_BAD_FAR_IMAGE,
  B_PERCO_ABSENT_FAR_IMAGE,
  B_PERCO_NO_VIEW
};


//various flags:

//Settings flags
#define B_PERCO_VERBOSE			0x00000007
#define B_PERCO_INFORMATION		0x00000004
#define B_PERCO_ERRORONLY		0x00000003
#define B_PERCO_NOTICES			0x00000002
#define B_PERCO_REPORT			0x00000001

//status flags
#define B_PERCO_START			0x00000003
#define B_PERCO_OK				0x00000000
#define B_PERCO_UNINITIALIZED	0x00000001
#define B_PERCO_UNLOADED		0x00000002
#define B_PERCO_INACTIVE		0x00000004
#define B_PERCO_BROKEN			0x00000010
#define B_PERCO_NO_VIEW			0x00000020

#if __B_NAMESPACED
};
#endif

#endif